# coding: utf-8

import json
from os.path import normpath, join
from django.conf import settings

from kinder import config_parser as config

DEFAULT_CONFIG = {
    ('webservice', 'SMEV_CONCENTRATOR_REG_CODE'): '',
    ('webservice', 'SMEV_CONCENTRATOR_WSDL_URL'): '',
    ('webservice', 'SMEV_CONCENTRATOR_WSDL_FILE'): '',
    ('webservice', 'TNS'): '',
    ('webservice', 'ADDXSITYPE'): False,
    ('webservice', 'GET_APPQ_FULL'): True,
    ('webservice', 'SET_NOTIFICATION_TYPE'): False,
    ('webservice', 'MAX_BINARY_DATA_SIZE'): 0
}

conf = config.ProjectConfig(
    filenames=[normpath(join(settings.CONFIG_PATH, 'concentrator.conf'))],
    defaults=DEFAULT_CONFIG
)
# Код региона
SMEV_CONCENTRATOR_REG_CODE = conf.get('webservice',
                                      'SMEV_CONCENTRATOR_REG_CODE')
# Адрес концентратора для отправки справочникоа
SMEV_CONCENTRATOR_WSDL_URL = conf.get('webservice',
                                      'SMEV_CONCENTRATOR_WSDL_URL')
# Адрес до файла с wsdl концентратора для формирования запроса на отправку,
# по умолчанию совпадает с SMEV_CONCENTRATOR_WSDL_URL
SMEV_CONCENTRATOR_WSDL_FILE = (conf.get('webservice',
                                        'SMEV_CONCENTRATOR_WSDL_FILE')
                              or SMEV_CONCENTRATOR_WSDL_URL)
TNS = conf.get('webservice', 'TNS')
# Настройка для подменый неймспеса у тэга AppData
ADDXSITYPE = conf.get_bool('webservice', 'ADDXSITYPE')
# Признак отдавать или нет детальную очередт в сервисе GetApplicationQueue
GET_APPQ_FULL = conf.get_bool('webservice', 'GET_APPQ_FULL')

LOAD_DATA_TIMEOUT = conf.get_int(
    'webservice', 'LOAD_DATA_TIMEOUT') or 90

SET_NOTIFICATION_TYPE = conf.get_bool('webservice', 'SET_NOTIFICATION_TYPE')

SEND_STATE_WITH_USER_COMMENTARY = conf.get_bool(
    'webservice', 'SEND_STATE_WITH_USER_COMMENTARY')

MAX_BINARY_DATA_SIZE = conf.get_int(
    'webservice', 'MAX_BINARY_DATA_SIZE') or 0

# Настройки запуска обработки Услуга "Проверить очередность. Получение сведений о зачвке"
#  Concentrator смэв3, поумолчанию каждые 5 минут
GET_APP_TASK_EVERY_MINUTE = conf.get('webservice',
                                      'GET_APP_TASK_EVERY_MINUTE') or '*/5'
GET_APP_TASK_EVERY_HOUR = conf.get('webservice',
                                      'GET_APP_TASK_EVERY_HOUR') or '*'
GET_APP_MESSAGE_TYPE = conf.get(
    'webservice', 'GET_APP_MESSAGE_TYPE') or 'Concentrator/GetApplicationRequest'
# Настройки запуска обработки Услуга "Проверить очередность" Concentrator смэв3
# поумолчанию каждые 5 минут
GET_APP_QUE_TASK_EVERY_MINUTE = conf.get('webservice',
                                      'GET_APP_QUE_TASK_EVERY_MINUTE') or '*/5'
GET_APP_QUE_TASK_EVERY_HOUR = conf.get('webservice',
                                      'GET_APP_QUE_TASK_EVERY_HOUR') or '*'
GET_APP_QUE_MESSAGE_TYPE = conf.get(
    'webservice', 'GET_APP_QUE_MESSAGE_TYPE') or 'Concentrator/GetApplicationQueueRequest'

APPLICATION_CHOOSE_TASK_EVERY_MINUTE = conf.get('webservice', 'APPLICATION_CHOOSE_TASK_EVERY_MINUTE') or '*/5'
APPLICATION_CHOOSE_TASK_EVERY_HOUR = conf.get('webservice', 'APPLICATION_CHOOSE_TASK_EVERY_HOUR') or '*'
APPLICATION_CHOOSE_MESSAGE_TYPE = conf.get('webservice', 'APPLICATION_CHOOSE_MESSAGE_TYPE') or 'Concentrator/ApplicationChooseRequest'
EVENT_SERVICE_ENV = conf.get('webservice', 'EVENT_SERVICE_ENV') or 'DEV'
EVENT_SERVICE_MESSAGE_TYPE = conf.get('webservice', 'EVENT_SERVICE_MESSAGE_TYPE') or 'eventServiceResponse'

# Настройки запуска обработки услуги "Подать заявление" Concentrator смэв3
# по-умолчанию каждые 5 минут

APP_REQ_TASK_EVERY_MINUTE = conf.get('webservice',
                                      'APP_REQ_TASK_EVERY_MINUTE') or '*/5'
APP_REQ_TASK_EVERY_HOUR = conf.get('webservice',
                                      'APP_REQ_TASK_EVERY_HOUR') or '*'
APP_REQ_MESSAGE_TYPE = conf.get(
    'webservice', 'APP_REQ_MESSAGE_TYPE') or 'Concentrator/ApplicationRequest'

# Настройки списка статусов организаций для отправки справочника Организации
# через метод LoadData, по умолчанию (если не настроен) включены статусы
# 0, 1, 2, 3, 4, 5.
STATUS_UNIT_LIST = json.loads(
    '['+conf.get('webservice', 'STATUS_UNIT_LIST')+']') or [0, 1, 2, 3, 4, 5]
